@@ -1,24 +1,10 @@
-#
-#   TTR: Technical Trading Rules
-#
-#   Copyright (C) 2007-2008  Joshua M. Ulrich
-#
-#   This program is free software: you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
-#   (at your option) any later version.
-#
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#
-#   You should have received a copy of the GNU General Public License
-#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+#-------------------------------------------------------------------------#
+# TTR, copyright (C) Joshua M. Ulrich, 2007                               #
+# Distributed under GNU GPL version 3                                     #
+#-------------------------------------------------------------------------#
 
 "MACD" <-
-function(x, nFast=12, nSlow=26, nSig=9, maType, percent=TRUE, ...) {
+function(x, nFast=12, nSlow=26, nSig=9, maType="EMA", percent=TRUE, ...) {
 
   # Oscillators
 
@@ -43,11 +29,6 @@ function(x, nFast=12, nSlow=26, nSig=9, maType, percent=TRUE, ...) {
   # containing MAs, which would allow the oscillator to be constructed
   # using MAs of different prices.
 
-  # Default MA
-  if(missing(maType)) {
-    maType <- 'EMA'
-  }
-
   # Case of two different 'maType's for both MAs.
   if( is.list(maType) ) {
 
