@@ -1,5 +1,10 @@
-"bollingerBands" <-
-function(HLC, ma = list("SMA", n=20), sd = list(FUN="sd", n=2)) {
+#-------------------------------------------------------------------------#
+# TTR, copyright (C) Joshua M. Ulrich, 2007                               #
+# Distributed under GNU GPL version 3                                     #
+#-------------------------------------------------------------------------#
+
+"BBands" <-
+function(HLC, n=20, maType="SMA", sd=2, ...) {
 
   # Bollinger Bands
 
@@ -11,25 +16,24 @@ function(HLC, ma = list("SMA", n=20), sd = list(FUN="sd", n=2)) {
   # http://stockcharts.com/education/IndicatorAnalysis/indic_BBWidth.htm
 
   if(NCOL(HLC)==1) {
-    message("Using Close/univariate price series."); flush.console()
     HLC <- as.vector(HLC)
   } else
 
   if(NCOL(HLC)==3) {
-    message("Using typical price series."); flush.console()
     HLC <- rowMeans(HLC)
   } else
 
   stop("Price series must be either High-Low-Close, or Close/univariate.")
 
-  mavg  <- do.call( ma[[1]], c( list(HLC), ma[-1] ) )
+  maArgs <- list(n=n, ...)
+  mavg  <- do.call( maType, c( list(HLC), maArgs ) )
 
   # Calculate standard deviation by hand to incorporate various MAs
-  sdev   <- rollFUN(HLC, ma$n, FUN=sd$FUN)
+  sdev   <- sqrt( runVar(HLC, n) )
 
-  up     <- mavg + sd$n * sdev
-  dn     <- mavg - sd$n * sdev
-  pct.b  <- (HLC - dn) / (up - dn)
+  up     <- mavg + sd * sdev
+  dn     <- mavg - sd * sdev
+  pctB  <- (HLC - dn) / (up - dn)
 
-  return( cbind(dn, mavg, up, pct.b) )
+  return( cbind(dn, mavg, up, pctB) )
 }
