@@ -1,5 +1,10 @@
+#-------------------------------------------------------------------------#
+# TTR, copyright (C) Joshua M. Ulrich, 2007                               #
+# Distributed under GNU GPL version 3                                     #
+#-------------------------------------------------------------------------#
+
 "ROC" <-
-function(x, n=1, type=c("discrete","continuous"), na=NA) {
+function(x, n=1, type=c("continuous","discrete"), na=NA) {
 
   # Rate of Change
 
@@ -10,22 +15,22 @@ function(x, n=1, type=c("discrete","continuous"), na=NA) {
 
   x    <- as.vector(x)
   roc  <- vector("numeric", NROW(x))
-  type <- match.arg(type)
+  #type <- match.arg(type) match.arg only works with 1 arg cleanly -jar
 
   # Discrete changes
-  if(type=="discrete") {
+  if(type[1]=="discrete") {
     roc <- c( rep(na,n),      x[(1+n):NROW(x)] / x[1:(NROW(x)-n)] -1 )
   }
 
   # Continuous changes
-  if(type=="continuous") {
+  if(type[1]=="continuous") {
     roc <- c( rep(na,n), log( x[(1+n):NROW(x)] / x[1:(NROW(x)-n)] )  )
   }
 
   return( roc )
 }
 
-# -----------------------------------------------------------
+#-------------------------------------------------------------------------#
 
 "momentum" <-
 function(x, n=1, na=NA) {
@@ -39,4 +44,4 @@ function(x, n=1, na=NA) {
   mom <- c( rep(na, n), diff(x, n) )
 
   return( mom )
-}
\ No newline at end of file
+}
